#include <stdio.h>
#include <stdlib.h>
#include <math.h>

/**
 * Calculate pi using the Nilakantha series:
 * π = 3 + 4/(2×3×4) - 4/(4×5×6) + 4/(6×7×8) - ...
 * 
 * Author: Matthew Pham
 * CSE 333
 * Exercise 0
 */

double calculate_nth_term(int n) {
    if (n == 0) {
        return 3.0; 
    }
    
    int sign = (n % 2 == 1) ? 1 : -1;  
    double denominator = (2.0 * n) * (2.0 * n + 1) * (2.0 * n + 2);
    
    return sign * 4.0 / denominator;
}

double calculate_pi(int n) {
    double pi = 0.0;
    
    for (int i = 0; i <= n; i++) {
        pi += calculate_nth_term(i);
    }
    
    return pi;
}

int main(int argc, char *argv[]) {
    if (argc != 2) {
        fprintf(stderr, "Usage: %s n\n", argv[0]);
        fprintf(stderr, "  where n is the number of terms to include in the Nilakantha series\n");
        return 1;
    }
    
    char *endptr;
    long n = strtol(argv[1], &endptr, 10);
    
    if (*endptr != '\0' || n < 0) {
        fprintf(stderr, "Error: Please provide a non-negative integer\n");
        return 1;
    }
    
    double pi = calculate_pi(n);
    
    printf("Our estimate of Pi is %.20f\n", pi);
    
    return 0;
}